==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/autostatus.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>AutoStatus</name>
    <message>
        <source>Auto status</source>
        <translation>Автостатус</translation>
    </message>
    <message>
        <source>Status changed automatically to &apos;away&apos;</source>
        <translation>Статус автоматически изменён на &apos;ушёл&apos;</translation>
    </message>
    <message>
        <source>Auto Status</source>
        <translation>Авто статус</translation>
    </message>
    <message>
        <source>Allows to change the status in accordance with the time of inactivity</source>
        <translation>Позволяет менять статус в зависимости от времени бездействия</translation>
    </message>
</context>
<context>
    <name>StatusOptionsWidget</name>
    <message>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Auto status: away</source>
        <translation>Автостатус: ушёл</translation>
    </message>
    <message>
        <source>You can insert date and time into auto status text:</source>
        <translation>Вы можете вставлять дату и время в текст автостатуса:</translation>
    </message>
    <message>
        <source>   %(&lt;format&gt;) - current date and time</source>
        <translation>   %(&lt;формат&gt;) - текущая дата и время</translation>
    </message>
    <message>
        <source>   $(&lt;format&gt;) - date and time you are idle form</source>
        <translation>   $(&lt;формат&gt;) - дата и время начала бездействия</translation>
    </message>
    <message>
        <source>   #(&lt;format&gt;) - time you are idle for</source>
        <translation>   #(&lt;формат&gt;) - время бездействия</translation>
    </message>
    <message>
        <source>Date Format:</source>
        <translation>Формат даты:</translation>
    </message>
    <message>
        <source>   d - the day as number without a leading zero (1 to 31)</source>
        <translation>   d - день в виде числа без ведущего нуля (1 - 31)</translation>
    </message>
    <message>
        <source>   dd - the day as number with a leading zero (01 to 31)</source>
        <translation>   dd - день в виде числа с ведущим нулём (01 - 31)</translation>
    </message>
    <message>
        <source>   ddd - the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;)</source>
        <translation>   ddd - аббревиатурное локализованное наименование дня недели (&apos;Пн&apos; - &apos;Вск&apos;)</translation>
    </message>
    <message>
        <source>   dddd - the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;)</source>
        <translation>   dddd - полное локализованное наименование дня недели (&apos;Понедельник&apos; - &apos;Воскресенье&apos;)</translation>
    </message>
    <message>
        <source>   M - the month as number without a leading zero (1-12)</source>
        <translation>   M - месяц в виде числа без ведущего нуля (1 - 12)</translation>
    </message>
    <message>
        <source>   MM - the month as number with a leading zero (01-12)</source>
        <translation>   MM - месяц в виде числа с ведущим нулём (01 - 12)</translation>
    </message>
    <message>
        <source>   MMM - the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;)</source>
        <translation>   MMM - аббревиатурное локализованное наименование месяца (&apos;Янв&apos; - &apos;Дек&apos;)</translation>
    </message>
    <message>
        <source>   MMMM - the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;)</source>
        <translation>   MMMM - полное локализованное наименование месяца (&apos;Январь&apos; - &apos;Декабрь&apos;)</translation>
    </message>
    <message>
        <source>   yy - the year as two digit number (00-99)</source>
        <translation>   yy - год в виде двухзначного числа (00 - 99)</translation>
    </message>
    <message>
        <source>   yyyy - the year as four digit number</source>
        <translation>   yyyy - год в виде четырёхзначного числа</translation>
    </message>
    <message>
        <source>Time Format:</source>
        <translation>Формат времени:</translation>
    </message>
    <message>
        <source>   h - the hour without a leading zero (0 to 23 or 1 to 12 if AM/PM display)</source>
        <translation>   h - час без ведущего нуля (0-23 или 1-12 если используется AM/PM)</translation>
    </message>
    <message>
        <source>   hh - the hour with a leading zero (00 to 23 or 01 to 12 if AM/PM display)</source>
        <translation>   hh - час с ведущим нулём (00-23 или 01-12 если используется AM/PM)</translation>
    </message>
    <message>
        <source>   H - the hour without a leading zero (0 to 23, even with AM/PM display)</source>
        <translation>   H - час без ведущего нуля (0-23 даже если используется AM/PM)</translation>
    </message>
    <message>
        <source>   HH - the hour with a leading zero (00 to 23, even with AM/PM display)</source>
        <translation>   HH - час с ведущим нулём (00-23 даже если используется AM/PM)</translation>
    </message>
    <message>
        <source>   m - the minute without a leading zero (0 to 59)</source>
        <translation>   m - минуты без ведущего нуля (0 - 59)</translation>
    </message>
    <message>
        <source>   mm - the minute with a leading zero (00 to 59)</source>
        <translation>   mm - минуты с ведущим нулём (00 - 59)</translation>
    </message>
    <message>
        <source>   s - the second without a leading zero (0 to 59)</source>
        <translation>   s - секунды без ведущего нуля (0 - 59)</translation>
    </message>
    <message>
        <source>   ss - the second with a leading zero (00 to 59)</source>
        <translation>   ss - секунды с ведущим нулём (00 - 59)</translation>
    </message>
    <message>
        <source>   z - the milliseconds without leading zeroes (0 to 999)</source>
        <translation>   z - миллисекунды без ведущего нуля (0 - 999)</translation>
    </message>
    <message>
        <source>   zzz - the milliseconds with leading zeroes (000 to 999)</source>
        <translation>   zzz - миллисекунды с ведущим нулём (000 - 999)</translation>
    </message>
    <message>
        <source>   AP or A - interpret as an AM/PM time. AP must be either &apos;AM&apos; or &apos;PM&apos;</source>
        <translation>   AP или A - интерпретируется как AM/PM время. AP должен быть либо &apos;AM&apos; либо &apos;PM&apos;</translation>
    </message>
    <message>
        <source>   ap or a - interpret as an AM/PM time. ap must be either &apos;am&apos; or &apos;pm&apos;</source>
        <translation>   ap или a - интерпретируется как AM/PM время. ap должен быть либо &apos;am&apos; либо &apos;pm&apos;</translation>
    </message>
    <message>
        <source>Example:</source>
        <translation>Пример:</translation>
    </message>
    <message>
        <source>Auto Status</source>
        <translation>Авто статус</translation>
    </message>
    <message>
        <source>   Status is set to &apos;away&apos; at %(hh:mm:ss), because of idle from $(hh:mm:ss) for #(mm) minutes and #(ss) seconds</source>
        <translation>   Статус изменён на ушёл&apos; в %(hh:mm:ss) из-за бездействия с $(hh:mm:ss) в течение #(mm) минут и #(ss) секунд</translation>
    </message>
</context>
<context>
    <name>StatusOptionsWidgetClass</name>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/ru/autostatus.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>AutoStatus</name>
    <message>
        <source>Auto status</source>
        <translation>Автостатус</translation>
    </message>
    <message>
        <source>Status changed automatically to &apos;away&apos;</source>
        <translation>Статус автоматически изменён на &apos;ушёл&apos;</translation>
    </message>
    <message>
        <source>Auto Status</source>
        <translation>Авто статус</translation>
    </message>
    <message>
        <source>Allows to change the status in accordance with the time of inactivity</source>
        <translation>Позволяет менять статус в зависимости от времени бездействия</translation>
    </message>
</context>
<context>
    <name>StatusOptionsWidget</name>
    <message>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Auto status: away</source>
        <translation>Автостатус: ушёл</translation>
    </message>
    <message>
        <source>You can insert date and time into auto status text:</source>
        <translation>Вы можете вставлять дату и время в текст автостатуса:</translation>
    </message>
    <message>
        <source>   %(&lt;format&gt;) - current date and time</source>
        <translation>   %(&lt;формат&gt;) - текущая дата и время</translation>
    </message>
    <message>
        <source>   $(&lt;format&gt;) - date and time you are idle form</source>
        <translation>   $(&lt;формат&gt;) - дата и время начала бездействия</translation>
    </message>
    <message>
        <source>   #(&lt;format&gt;) - time you are idle for</source>
        <translation>   #(&lt;формат&gt;) - время бездействия</translation>
    </message>
    <message>
        <source>Date Format:</source>
        <translation>Формат даты:</translation>
    </message>
    <message>
        <source>   d - the day as number without a leading zero (1 to 31)</source>
        <translation>   d - день в виде числа без ведущего нуля (1 - 31)</translation>
    </message>
    <message>
        <source>   dd - the day as number with a leading zero (01 to 31)</source>
        <translation>   dd - день в виде числа с ведущим нулём (01 - 31)</translation>
    </message>
    <message>
        <source>   ddd - the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;)</source>
        <translation>   ddd - аббревиатурное локализованное наименование дня недели (&apos;Пн&apos; - &apos;Вск&apos;)</translation>
    </message>
    <message>
        <source>   dddd - the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;)</source>
        <translation>   dddd - полное локализованное наименование дня недели (&apos;Понедельник&apos; - &apos;Воскресенье&apos;)</translation>
    </message>
    <message>
        <source>   M - the month as number without a leading zero (1-12)</source>
        <translation>   M - месяц в виде числа без ведущего нуля (1 - 12)</translation>
    </message>
    <message>
        <source>   MM - the month as number with a leading zero (01-12)</source>
        <translation>   MM - месяц в виде числа с ведущим нулём (01 - 12)</translation>
    </message>
    <message>
        <source>   MMM - the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;)</source>
        <translation>   MMM - аббревиатурное локализованное наименование месяца (&apos;Янв&apos; - &apos;Дек&apos;)</translation>
    </message>
    <message>
        <source>   MMMM - the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;)</source>
        <translation>   MMMM - полное локализованное наименование месяца (&apos;Январь&apos; - &apos;Декабрь&apos;)</translation>
    </message>
    <message>
        <source>   yy - the year as two digit number (00-99)</source>
        <translation>   yy - год в виде двухзначного числа (00 - 99)</translation>
    </message>
    <message>
        <source>   yyyy - the year as four digit number</source>
        <translation>   yyyy - год в виде четырёхзначного числа</translation>
    </message>
    <message>
        <source>Time Format:</source>
        <translation>Формат времени:</translation>
    </message>
    <message>
        <source>   h - the hour without a leading zero (0 to 23 or 1 to 12 if AM/PM display)</source>
        <translation>   h - час без ведущего нуля (0-23 или 1-12 если используется AM/PM)</translation>
    </message>
    <message>
        <source>   hh - the hour with a leading zero (00 to 23 or 01 to 12 if AM/PM display)</source>
        <translation>   hh - час с ведущим нулём (00-23 или 01-12 если используется AM/PM)</translation>
    </message>
    <message>
        <source>   H - the hour without a leading zero (0 to 23, even with AM/PM display)</source>
        <translation>   H - час без ведущего нуля (0-23 даже если используется AM/PM)</translation>
    </message>
    <message>
        <source>   HH - the hour with a leading zero (00 to 23, even with AM/PM display)</source>
        <translation>   HH - час с ведущим нулём (00-23 даже если используется AM/PM)</translation>
    </message>
    <message>
        <source>   m - the minute without a leading zero (0 to 59)</source>
        <translation>   m - минуты без ведущего нуля (0 - 59)</translation>
    </message>
    <message>
        <source>   mm - the minute with a leading zero (00 to 59)</source>
        <translation>   mm - минуты с ведущим нулём (00 - 59)</translation>
    </message>
    <message>
        <source>   s - the second without a leading zero (0 to 59)</source>
        <translation>   s - секунды без ведущего нуля (0 - 59)</translation>
    </message>
    <message>
        <source>   ss - the second with a leading zero (00 to 59)</source>
        <translation>   ss - секунды с ведущим нулём (00 - 59)</translation>
    </message>
    <message>
        <source>   z - the milliseconds without leading zeroes (0 to 999)</source>
        <translation>   z - миллисекунды без ведущего нуля (0 - 999)</translation>
    </message>
    <message>
        <source>   zzz - the milliseconds with leading zeroes (000 to 999)</source>
        <translation>   zzz - миллисекунды с ведущим нулём (000 - 999)</translation>
    </message>
    <message>
        <source>   AP or A - interpret as an AM/PM time. AP must be either &apos;AM&apos; or &apos;PM&apos;</source>
        <translation>   AP или A - интерпретируется как AM/PM время. AP должен быть либо &apos;AM&apos; либо &apos;PM&apos;</translation>
    </message>
    <message>
        <source>   ap or a - interpret as an AM/PM time. ap must be either &apos;am&apos; or &apos;pm&apos;</source>
        <translation>   ap или a - интерпретируется как AM/PM время. ap должен быть либо &apos;am&apos; либо &apos;pm&apos;</translation>
    </message>
    <message>
        <source>Example:</source>
        <translation>Пример:</translation>
    </message>
    <message>
        <source>Auto Status</source>
        <translation>Авто статус</translation>
    </message>
    <message>
        <source>   Status is set to &apos;away&apos; at %(hh:mm:ss), because of idle from $(hh:mm:ss) for #(mm) minutes and #(ss) seconds</source>
        <translation>   Статус изменён на &apos;ушёл&apos; в %(hh:mm:ss) из-за бездействия с $(hh:mm:ss) в течение #(mm) минут и #(ss) секунд</translation>
    </message>
</context>
<context>
    <name>StatusOptionsWidgetClass</name>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
</context>
</TS>
